X10 DB/cache library API and reference implementation

# Description

Library is intended for accessing of "key-value" databases.
It should be used for caches in igmpd, mac table and anywhere else.

API allows program to work with any physical database: it depends
on selected driver.

# Drivers

## memdb

Simple memory database engine. Connect via libsw_get_db_api()
passing `NULL` as the first argument. See libsw_get_memdb_api() for
additional information.

# Build

    autoreconf -fiv
    ./configure
    make

# Usage

    #include <x10/libdb.h>

    libsw_db_api_t *dbapi;
    libsw_db_t *sensor_db;
    sensor_t *sensor;
    int i;

    dbapi = libsw_get_db_api( NULL, NULL );
    if ( ! dbapi ) {
      ERR( "Unable to connect to the DB" );
      return 1;
    }

    sensor_db = dbapi->open( dbapi,
                             "status/temperature", // DB name
                             100,                  // record count
                             sizeof( sensor_t ),   // record size
                             0,                    // flags
                             NULL, NULL );
    if ( ! sensor_db ) {
      ERR( "Unable to open the status/temperature DB" );
      return 1;
    }

    for ( i = 0; i < sensor_db->get_count( sensor_db ); i++ ) {
      sensor = sensor_db->get_record( sensor_db, i );
      if ( strncmp( sensor->name, "CPU", strlen( "CPU" )) == 0 )
      {
        sensor_db->lock_record(sensor_db, sensor);
        sensor->value += 10; // modifying the value
        sensor_db->unlock_record(sensor_db, sensor); // commit changes
      }
    }

    sensor_db->close( sensor_db );
    dbapi->close( dbapi );
