#ifndef LIBMEMDB_H
#define LIBMEMDB_H

/* Includes */

#include "libdb.h"

/* Types */

/**
 * Memory mapped file DB descriptor.
 */
typedef struct libsw_obj_db
{
  void *head;      ///< The start of the mapped memory area.
  int fd;          ///< The memory-mapped file descriptor (number).
  size_t isize;    ///< The size of the DB item (record).
  uint16_t count;  ///< The number of items (records) in the DB
                   ///<  (the length of the file).
  char filename[ 256 ];  ///< The name of the memory-mapped file.
} libsw_obj_db_t;


/**
 * Memory mapped DBA configuration.
 *
 * @sa #libsw_get_memdb_api.
 */
typedef struct libsw_memdb_api
{
  char dir[ 256 ];  ///< The directory for the DB files.
  uid_t uid;        ///< The file owner user name.
  gid_t gid;        ///< The file group name.
  mode_t mode;      ///< The file access mode (permissions).
} libsw_memdb_api_t;


/* Functions (forward declarations) */

int libsw_load_obj_db( libsw_obj_db_t *db, libsw_db_loader_t loader,
                       void *ctx );

void *libsw_get_obj_db_item( libsw_obj_db_t *db, uint16_t idx );

uint16_t libsw_get_obj_db_index( libsw_obj_db_t *db,
                                 const void *item );

int libsw_lock_obj_db( libsw_obj_db_t *db );

int libsw_unlock_obj_db( libsw_obj_db_t *db );

int libsw_lock_obj_db_item( libsw_obj_db_t *db, const void *item );

int libsw_unlock_obj_db_item( libsw_obj_db_t *db, const void *item );


/* DB API functions */

libsw_db_api_t *libsw_get_memdb_api( const char *config );

#endif
